# jeckin
[![Upload Python Package](https://github.com/aarestu/jeckin/actions/workflows/python-publish.yml/badge.svg)](https://github.com/aarestu/jeckin/actions/workflows/python-publish.yml) [![PyPI version](https://badge.fury.io/py/jeckin.svg)](https://badge.fury.io/py/jeckin)

SSH HTTP Injector

## Requirement
python >= 3. < 4

## Installation
```
$ pip install jeckin
```

## Usage
Generate template config file
```
jeckin myconfig.hj
```

Run service
```
jeckin myconfig.hj
```
